@@ -9,5 +9,7 @@ int stl_mode_converter(string input_fname,
 					   int progress_part,
 					   void(*callback)(int, void*),
 					   void* py_callback,
-					   void* py_progress);
+					   void* py_progress,
+					   bool is_next
+	);
 string get_stl_mode(string file);
